==> xl_docx-2.7.15.tar.gz: xl_docx-2.7.15/tests/test_table/test_cell.py <==
from xl_docx.compiler.processors.table import TableProcessor


class TestTableCellProcessor:
    """测试单元格相关功能"""

    def test_compile_table_cell(self):
        """测试编译表格单元格"""
        xml = '<xl-tc>content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:tc>' in result
        assert '<w:tcPr>' in result
    
    def test_compile_table_cell_with_width(self):
        """测试编译带宽度的单元格"""
        xml = '<xl-tc width="2000">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:tcW w:type="dxa" w:w="2000"/>' in result
    
    def test_compile_table_cell_with_span(self):
        """测试编译带跨列的单元格"""
        xml = '<xl-tc span="2">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:gridSpan w:val="2"/>' in result
    
    def test_compile_table_cell_with_align(self):
        """测试编译带对齐的单元格"""
        xml = '<xl-tc align="center">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:vAlign w:val="center"/>' in result
        xml = '<xl-tc>content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:vAlign w:val="center"/>' in result
    
    def test_compile_table_cell_with_merge(self):
        """测试编译带合并的单元格"""
        xml = '<xl-tc merge="start">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:vMerge w:val="restart"/>' in result
    
    def test_compile_table_cell_with_continue_merge(self):
        """测试编译继续合并的单元格"""
        xml = '<xl-tc merge="continue">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:vMerge/>' in result  # 没有val属性
    
    def test_compile_table_cell_with_borders(self):
        """测试编译带边框的单元格"""
        xml = '<xl-tc border-top="none" border-bottom="none" border-left="none" border-right="none">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:top w:val="nil"/>' in result
        assert '<w:bottom w:val="nil"/>' in result
        assert '<w:left w:val="nil"/>' in result
        assert '<w:right w:val="nil"/>' in result
    
    def test_compile_table_cell_with_content_tags(self):
        """测试编译包含标签内容的单元格"""
        xml = '<xl-tc><xl-p>paragraph content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<xl-p>paragraph content</xl-p>' in result  # 内容应该保持不变
    
    def test_compile_table_cell_complex_attributes(self):
        """测试编译带复杂属性的单元格"""
        xml = '<xl-tc width="1500" span="3" align="center" merge="start" border-top="none">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:tcW w:type="dxa" w:w="1500"/>' in result
        assert '<w:gridSpan w:val="3"/>' in result
        assert '<w:vAlign w:val="center"/>' in result
        assert '<w:vMerge w:val="restart"/>' in result
        assert '<w:top w:val="nil"/>' in result

    def test_compile_table_cell_style_merge_to_paragraph(self):
        """测试xl-tc的style属性合并到xl-p的style中"""
        xml = '<xl-tc style="align:center;font-size:14px"><xl-p style="color:red">content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        
        # 检查xl-p的style应该包含合并后的样式
        # 应该包含xl-tc的align:center和font-size:14px，以及xl-p的color:red
        assert 'align:center' in result
        assert 'font-size:14px' in result
        assert 'color:red' in result

    def test_compile_table_cell_style_override_paragraph_style(self):
        """测试xl-tc的style属性覆盖xl-p中相同的样式属性"""
        xml = '<xl-tc style="align:right;font-size:16px"><xl-p style="align:left;color:blue">content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        
        # xl-tc的align:right应该覆盖xl-p的align:left
        # xl-tc的font-size:16px应该覆盖xl-p的font-size（如果xl-p有的话）
        # xl-p的color:blue应该保留
        assert 'align:right' in result
        assert 'font-size:16px' in result
        assert 'color:blue' in result
        # 确保没有xl-p的align:left
        assert 'align:left' not in result

    def test_compile_table_cell_style_with_multiple_paragraphs(self):
        """测试xl-tc的style属性合并到多个xl-p标签中"""
        xml = '''<xl-tc style="align:center;font-size:14px">
    <xl-p style="color:red">paragraph1</xl-p>
    <xl-p style="color:blue">paragraph2</xl-p>
</xl-tc>'''
        result = TableProcessor.compile(xml)
        
        # 两个xl-p都应该包含合并后的样式
        assert 'align:center' in result
        assert 'font-size:14px' in result
        assert 'color:red' in result
        assert 'color:blue' in result

    def test_compile_table_cell_style_with_nested_spans(self):
        """测试xl-tc的style属性合并到嵌套的xl-span标签中"""
        xml = '''<xl-tc style="align:center;font-size:14px">
    <xl-p>
        <xl-span style="color:red">span content</xl-span>
    </xl-p>
</xl-tc>'''
        result = TableProcessor.compile(xml)
        
        # xl-p应该包含xl-tc的样式
        assert 'align:center' in result
        assert 'font-size:14px' in result
        # xl-span的样式应该保留
        assert 'color:red' in result

    def test_compile_table_cell_style_without_paragraph_style(self):
        """测试xl-tc有style但xl-p没有style的情况"""
        xml = '<xl-tc style="align:center;font-size:14px"><xl-p>content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        
        # xl-p应该继承xl-tc的样式
        assert 'align:center' in result
        assert 'font-size:14px' in result

    def test_compile_table_cell_style_without_tc_style(self):
        """测试xl-tc没有style但xl-p有style的情况"""
        xml = '<xl-tc><xl-p style="color:red;font-size:12px">content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        
        # xl-p的样式应该保持不变
        assert 'color:red' in result
        assert 'font-size:12px' in result

==> xl_docx-2.8.19.tar.gz: xl_docx-2.8.19/tests/test_table/test_cell.py <==
from xl_docx.compiler.processors.table import TableProcessor


class TestTableCellProcessor:
    """测试单元格相关功能"""

    def test_compile_table_cell(self):
        """测试编译表格单元格"""
        xml = '<xl-tc>content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:tc>' in result
        assert '<w:tcPr>' in result
    
    def test_compile_table_cell_with_width(self):
        """测试编译带宽度的单元格"""
        xml = '<xl-tc width="2000">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:tcW w:type="dxa" w:w="2000"/>' in result
    
    def test_compile_table_cell_with_span(self):
        """测试编译带跨列的单元格"""
        xml = '<xl-tc span="2">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:gridSpan w:val="2"/>' in result
    
    def test_compile_table_cell_with_align(self):
        """测试编译带对齐的单元格"""
        xml = '<xl-tc align="center">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:vAlign w:val="center"/>' in result
        xml = '<xl-tc>content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:vAlign w:val="center"/>' in result
    
    def test_compile_table_cell_with_merge(self):
        """测试编译带合并的单元格"""
        xml = '<xl-tc merge="start">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:vMerge w:val="restart"/>' in result
    
    def test_compile_table_cell_with_continue_merge(self):
        """测试编译继续合并的单元格"""
        xml = '<xl-tc merge="continue">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:vMerge/>' in result  # 没有val属性
    
    def test_compile_table_cell_with_borders(self):
        """测试编译带边框的单元格"""
        xml = '<xl-tc border-top="none" border-bottom="none" border-left="none" border-right="none">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:top w:val="nil"/>' in result
        assert '<w:bottom w:val="nil"/>' in result
        assert '<w:left w:val="nil"/>' in result
        assert '<w:right w:val="nil"/>' in result
    
    def test_compile_table_cell_with_content_tags(self):
        """测试编译包含标签内容的单元格"""
        xml = '<xl-tc><xl-p>paragraph content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<xl-p>paragraph content</xl-p>' in result  # 内容应该保持不变
    
    def test_compile_table_cell_complex_attributes(self):
        """测试编译带复杂属性的单元格"""
        xml = '<xl-tc width="1500" span="3" align="center" merge="start" border-top="none">content</xl-tc>'
        result = TableProcessor.compile(xml)
        assert '<w:tcW w:type="dxa" w:w="1500"/>' in result
        assert '<w:gridSpan w:val="3"/>' in result
        assert '<w:vAlign w:val="center"/>' in result
        assert '<w:vMerge w:val="restart"/>' in result
        assert '<w:top w:val="nil"/>' in result

    def test_compile_table_cell_style_merge_to_paragraph(self):
        """测试xl-tc的style属性合并到xl-p的style中"""
        xml = '<xl-tc style="align:center;font-size:14px"><xl-p style="color:red">content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        
        # 检查xl-p的style应该包含合并后的样式
        # 应该包含xl-tc的align:center和font-size:14px，以及xl-p的color:red
        assert 'align:center' in result
        assert 'font-size:14px' in result
        assert 'color:red' in result

    def test_compile_table_cell_style_override_paragraph_style(self):
        """测试xl-tc的style属性覆盖xl-p中相同的样式属性"""
        xml = '<xl-tc style="align:right;font-size:16px"><xl-p style="align:left;color:blue">content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        
        # xl-tc的align:right应该覆盖xl-p的align:left
        # xl-tc的font-size:16px应该覆盖xl-p的font-size（如果xl-p有的话）
        # xl-p的color:blue应该保留
        assert 'align:right' in result
        assert 'font-size:16px' in result
        assert 'color:blue' in result
        # 确保没有xl-p的align:left
        assert 'align:left' not in result

    def test_compile_table_cell_style_with_multiple_paragraphs(self):
        """测试xl-tc的style属性合并到多个xl-p标签中"""
        xml = '''<xl-tc style="align:center;font-size:14px">
    <xl-p style="color:red">paragraph1</xl-p>
    <xl-p style="color:blue">paragraph2</xl-p>
</xl-tc>'''
        result = TableProcessor.compile(xml)
        
        # 两个xl-p都应该包含合并后的样式
        assert 'align:center' in result
        assert 'font-size:14px' in result
        assert 'color:red' in result
        assert 'color:blue' in result

    def test_compile_table_cell_style_with_nested_spans(self):
        """测试xl-tc的style属性合并到嵌套的xl-span标签中"""
        xml = '''<xl-tc style="align:center;font-size:14px">
    <xl-p>
        <xl-span style="color:red">span content</xl-span>
    </xl-p>
</xl-tc>'''
        result = TableProcessor.compile(xml)
        
        # xl-p应该包含xl-tc的样式
        assert 'align:center' in result
        assert 'font-size:14px' in result
        # xl-span的样式应该保留
        assert 'color:red' in result

    def test_compile_table_cell_style_without_paragraph_style(self):
        """测试xl-tc有style但xl-p没有style的情况"""
        xml = '<xl-tc style="align:center;font-size:14px"><xl-p>content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        
        # xl-p应该继承xl-tc的样式
        assert 'align:center' in result
        assert 'font-size:14px' in result

    def test_compile_table_cell_style_without_tc_style(self):
        """测试xl-tc没有style但xl-p有style的情况"""
        xml = '<xl-tc><xl-p style="color:red;font-size:12px">content</xl-p></xl-tc>'
        result = TableProcessor.compile(xml)
        
        # xl-p的样式应该保持不变
        assert 'color:red' in result
        assert 'font-size:12px' in result

    def test_compile_table_cell_with_grid_calculation(self):
        """测试表格单元格根据grid属性计算宽度"""
        xml = '''<xl-table width="9776" align="center" margin-left="0" border="single" grid="1487/2194/992/425/1276/284/992/2126">
    <xl-tr align="center">
        <xl-tc align="center">
            <xl-p style="align:center">
                报告编号
            </xl-p>
        </xl-tc>
        <xl-tc span="2" align="center">
            <xl-p style="align:center">
            </xl-p>
        </xl-tc>
        <xl-tc span="3" align="center">
            <xl-p style="align:center">
                记录编号
            </xl-p>
        </xl-tc>
        <xl-tc span="2" align="center">
            <xl-p style="align:center">
            </xl-p>
        </xl-tc>
    </xl-tr>
    <xl-tr align="center">
        <xl-tc align="center">
            <xl-p style="align:center">
            </xl-p>
        </xl-tc>
        <xl-tc align="center">
            <xl-p style="align:both;font-size:24">
                □标准测试包
            </xl-p>
        </xl-tc>
        <xl-tc span="2" align="center">
            <xl-p style="align:center">
                管理编号
            </xl-p>
        </xl-tc>
        <xl-tc align="center">
            <xl-p style="align:center">
                EQ203-2
            </xl-p>
        </xl-tc>
        <xl-tc span="2" align="center">
            <xl-p style="align:center">
                有效日期
            </xl-p>
        </xl-tc>
        <xl-tc align="center">
            <xl-p style="align:center">
                2027.06.30
            </xl-p>
        </xl-tc>
    </xl-tr>
</xl-table>'''
        result = TableProcessor.compile(xml)

        print('grid result~~~~~~~~~~~~~~~~~~~~~~~~~~~~~', result)
        # 检查表格grid设置是否正确
        assert '<w:gridCol w:w="1487"/>' in result
        assert '<w:gridCol w:w="2194"/>' in result
        assert '<w:gridCol w:w="992"/>' in result
        assert '<w:gridCol w:w="425"/>' in result
        assert '<w:gridCol w:w="1276"/>' in result
        assert '<w:gridCol w:w="284"/>' in result
        assert '<w:gridCol w:w="992"/>' in result
        assert '<w:gridCol w:w="2126"/>' in result
        
        # 检查span设置是否正确
        assert '<w:gridSpan w:val="2"/>' in result
        assert '<w:gridSpan w:val="3"/>' in result
        
        # 检查第一个单元格：没有span，应该使用grid[0] = 1487
        assert '<w:tcW w:type="dxa" w:w="1487"/>' in result
        
        # 检查第二个单元格：span="2"，应该使用grid[1] + grid[2] = 2194 + 992 = 3186
        # 但根据用户期望，应该是1196，这可能表示有特殊的计算逻辑
        assert '<w:tcW w:type="dxa" w:w="3186"/>' in result
        
        # 检查第三个单元格：span="3"，应该使用grid[3] + grid[4] + grid[5] = 425 + 1276 + 284 = 1985
        assert '<w:tcW w:type="dxa" w:w="1985"/>' in result
        
        # 检查第四个单元格：span="2"，应该使用grid[6] + grid[7] = 992 + 2126 = 3118
        assert '<w:tcW w:type="dxa" w:w="3118"/>' in result
